==> httraqt_1.2.0.orig.tar.gz: httraqt/sources/main/includes/InsertUrlDialog.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2013 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef INSERTURL_H
#define INSERTURL_H

#include "ui_InsertUrlDialog.h"


class HTTraQt;

class InsertUrlDialog: public QDialog, public Ui_InsertUrlDialog
{
        Q_OBJECT
    public:
        InsertUrlDialog(QWidget *parent = 0);

    public slots:
        void onOk();
        void translate();

    public:
        QString m_urllogin;
        QString m_urlpass;
        QString m_urladr;

    private:
        HTTraQt* parent;
};

#endif

==> httraqt_1.3.0.orig.tar.gz: httraqt/sources/main/includes/InsertUrlDialog.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef INSERTURL_H
#define INSERTURL_H

#include "httraqt.h"
#include "ui_InsertUrlDialog.h"


class HTTraQt;

class InsertUrlDialog: public QDialog, public Ui_InsertUrlDialog, public Translator
{
        Q_OBJECT
    public:
        InsertUrlDialog(QWidget *parent = 0);

    public slots:
        void onOk();
        void translateDialog();

    public:
        QString m_urllogin;
        QString m_urlpass;
        QString m_urladr;

    private:
        HTTraQt* parent;
};

#endif
